oriole\_test package
====================

Submodules
----------

oriole\_test.cli module
-----------------------

.. automodule:: oriole_test.cli
    :members:
    :undoc-members:
    :show-inheritance:

oriole\_test.oriole\_test module
--------------------------------

.. automodule:: oriole_test.oriole_test
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: oriole_test
    :members:
    :undoc-members:
    :show-inheritance:
